==> okio-jvm-3.6.0-javadoc.jar: okio/okio/-i-o-exception/index.md <==
//[okio](../../../index.md)/[okio](../index.md)/[IOException](index.md)

# IOException

expect open class [IOException](index.md)(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)?, cause: [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html)?) : [Exception](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-exception/index.html)actual open class [IOException](index.md)(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)?, cause: [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html)?) : [Exception](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-exception/index.html)actual typealias [IOException](index.md) = [java.io.IOException](https://docs.oracle.com/javase/8/docs/api/java/io/IOException.html)

#### Inheritors

| |
|---|
| [ProtocolException](../-protocol-exception/index.md) |
| [EOFException](../-e-o-f-exception/index.md) |
| [FileNotFoundException](../-file-not-found-exception/index.md) |
| [ProtocolException](../-protocol-exception/index.md) |
| [EOFException](../-e-o-f-exception/index.md) |
| [FileNotFoundException](../-file-not-found-exception/index.md) |

## Constructors

| | |
|---|---|
| [IOException](-i-o-exception.md) | [common]<br>expect constructor(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)? = null)expect constructor(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)?, cause: [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html)?)<br>[nonJvm]<br>actual constructor(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)?)actual constructor(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)?, cause: [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html)?) |

## Properties

| Name | Summary |
|---|---|
| cause | [common, nonJvm]<br>[common]<br>open val [cause](../-file-not-found-exception/index.md#-654012527%2FProperties%2F1348982416): [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html)?<br>[nonJvm]<br>open val [cause](../-file-not-found-exception/index.md#-654012527%2FProperties%2F1730460553): [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html)? |
| message | [common, nonJvm]<br>[common]<br>open val [message](../-file-not-found-exception/index.md#1824300659%2FProperties%2F1348982416): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)?<br>[nonJvm]<br>open val [message](../-file-not-found-exception/index.md#1824300659%2FProperties%2F1730460553): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)? |

==> okio-jvm-3.7.0-javadoc.jar: okio/okio/-i-o-exception/index.md <==
//[okio](../../../index.md)/[okio](../index.md)/[IOException](index.md)

# IOException

expect open class [IOException](index.md)(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)?, cause: [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html)?) : [Exception](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-exception/index.html)actual open class [IOException](index.md)(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)?, cause: [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html)?) : [Exception](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-exception/index.html)actual typealias [IOException](index.md) = [java.io.IOException](https://docs.oracle.com/javase/8/docs/api/java/io/IOException.html)

#### Inheritors

| |
|---|
| [ProtocolException](../-protocol-exception/index.md) |
| [EOFException](../-e-o-f-exception/index.md) |
| [FileNotFoundException](../-file-not-found-exception/index.md) |
| [ProtocolException](../-protocol-exception/index.md) |
| [EOFException](../-e-o-f-exception/index.md) |
| [FileNotFoundException](../-file-not-found-exception/index.md) |

## Constructors

| | |
|---|---|
| [IOException](-i-o-exception.md) | [common]<br>expect constructor(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)?)expect constructor()expect constructor(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)?, cause: [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html)?)<br>[nonJvm]<br>actual constructor(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)?)actual constructor()actual constructor(message: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)?, cause: [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html)?) |

## Properties

| Name | Summary |
|---|---|
| cause | [common, nonJvm]<br>[common]<br>open val [cause](../-file-not-found-exception/index.md#-654012527%2FProperties%2F1348982416): [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html)?<br>[nonJvm]<br>open val [cause](../-file-not-found-exception/index.md#-654012527%2FProperties%2F1730460553): [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html)? |
| message | [common, nonJvm]<br>[common]<br>open val [message](../-file-not-found-exception/index.md#1824300659%2FProperties%2F1348982416): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)?<br>[nonJvm]<br>open val [message](../-file-not-found-exception/index.md#1824300659%2FProperties%2F1730460553): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)? |
